@@ -1,6 +1,7 @@
 import contextlib
 
 from inline_snapshot._rewrite_code import ChangeRecorder
+from inline_snapshot.extra import transformation
 
 
 @contextlib.contextmanager
@@ -9,3 +10,8 @@ def apply_changes():
     yield recorder
 
     recorder.fix_all()
+
+
+@transformation
+def path_transform(text):
+    return text.replace("\\", "/")
